==> digikam-3.0.0.tar.bz2: digikam-3.0.0/extra/kipi-plugins/timeadjust/kipiplugin_timeadjust.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=TimeDateAdjust
Name=TimeDateAdjust
Name[ar]=ضبط‌التاريخ‌الوقت
Name[ast]=TimeDateAdjust
Name[bg]=Нагласяване на дата и час
Name[bs]=Podešavanje vremena i datuma
Name[ca]=TimeDateAdjust
Name[ca@valencia]=TimeDateAdjust
Name[cs]=Úprava data a času
Name[da]=TimeDateAdjust
Name[de]=Zeit/Datum einstellen
Name[el]=TimeDateAdjust
Name[en_GB]=TimeDateAdjust
Name[es]=Ajustar fecha y hora
Name[et]=Aja kohendamine
Name[eu]=Ordua eta data doitzea
Name[fi]=Päiväyksen tarkistus
Name[fr]=Ajuster l'heure et la date
Name[ga]=TimeDateAdjust
Name[gl]=TimeDateAdjust
Name[he]=שינוי תאריך ושעה
Name[hne]=टाइम-डेट-एडजस्ट
Name[hu]=Dátum és idő beállítás
Name[is]=TimeDateAdjust
Name[it]=Regolazione di data e ora
Name[ja]=TimeDateAdjust
Name[km]=លៃតម្រូវ​កាលបរិច្ឆេទ/ពេលវេលា
Name[ko]=TimeDateAdjust
Name[lv]=Laika un datuma korekcija
Name[nb]=TimeDateAdjust
Name[nds]=TietDatumtopassen
Name[nl]=Tijd/DatumAanpassen
Name[pa]=ਟਾਈਮ ਮਿਤੀ ਅਡਜੱਸਟ
Name[pl]=DostrajanieCzasuDaty
Name[pt]=Ajuste de Data e Hora
Name[pt_BR]=Ajuste de data e hora
Name[ro]=Ajustare dată și oră
Name[ru]=Настройка даты и времени
Name[sk]=Oprava dátumu a času
Name[sl]=TimeDateAdjust
Name[sq]=Kohë Datë Rregullo
Name[sv]=Justera datum och tid
Name[th]=ปรับแก้ค่าวันที่และเวลาของภาพ
Name[tr]=Tarih Saat Ayarla
Name[uk]=TimeDateAdjust
Name[x-test]=xxTimeDateAdjustxx
Name[zh_CN]=时间数据调整
Name[zh_TW]=時間日期調整
Comment=A tool to adjust date and time
Comment[ast]=Una ferramienta p'axustar la data y la hora
Comment[bg]=Инструмент за нагласяване на датата и часа
Comment[bs]=Alat za podešavanje datuma i vremena
Comment[ca]=Una eina per a ajustar la data i l'hora
Comment[ca@valencia]=Una eina per a ajustar la data i l'hora
Comment[cs]=Nástroj pro úpravu data a času
Comment[da]=Et værktøj til at justere dato og tidspunkt
Comment[de]=Ein Werkzeug, um Datum und Zeit zu justieren.
Comment[el]=Εργαλείο ρύθμισης ημερομηνίας και ώρας
Comment[en_GB]=A tool to adjust date and time
Comment[es]=Una herramienta para ajustar la fecha y hora
Comment[et]=Tööriist kuupäeva ja kellaaja kohandamiseks
Comment[eu]=Ordua eta data doitzeko tresna
Comment[fr]=Outil pour ajuster la date et l'heure
Comment[ga]=Uirlis a choigeartaíonn an dáta agus an t-am
Comment[gl]=Unha ferramenta para axustar a data e a hora
Comment[he]=כלי לשינוי תאריך ושעה
Comment[hne]=तारीक अउ समय ल एडजस्ट करे के एक औजार
Comment[hu]=Egy eszköz dátum és idő beállításához
Comment[is]=Verkfæri til að breyta dagsetningu og tímamerkjum mynda
Comment[it]=Uno strumento per regolare la data e l'ora
Comment[ja]=日付と時刻を調整するツール
Comment[km]=ឧបករណ៍​ត្រូវ​លៃតម្រូវ​កាលបរិច្ឆេទ និង​ពេលវេលា
Comment[lv]=Rīks laika un datuma koriģēšanai
Comment[nb]=Et verktøy for å justere dato og klokkeslett
Comment[nds]=En Warktüüch, mit dat sik Datum un Tiet topassen laat
Comment[nl]=Een hulpmiddel voor het aanpassen van datum en tijd
Comment[pa]=ਮਿਤੀ ਅਤੇ ਟਾਈਮ ਅਡਜੱਸਟ ਕਰਨ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do dostrajania daty i czasu
Comment[pt]=Uma ferramenta para ajustar a data e hora
Comment[pt_BR]=Uma ferramenta para ajustar a data e a hora
Comment[ro]=O unealtă pentru ajustarea datei și orei 
Comment[ru]=Инструмент для настройки даты и времени
Comment[sk]=Nástroj na opravu dátumu a času
Comment[sl]=Orodje za nastavljanje datuma in časa
Comment[sq]=Një mjet për të rregulluar datën dhe orën
Comment[sv]=Ett verktyg för att justera datum och tid
Comment[th]=เครื่องมือในการปรับแก้วันที่และเวลาของภาพ
Comment[tr]=Tarihi ve saati ayarlamak için bir araç
Comment[uk]=Інструмент для налаштування дати і часу
Comment[x-test]=xxA tool to adjust date and timexx
Comment[zh_CN]=一个调整日期和时间的工具
Comment[zh_TW]=調整日期和時間的工具
Type=Service
Icon=timeadjust
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_timeadjust
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-ReqFeatures=ImagesHasTime
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}

==> digikam-4.4.0.tar.bz2: digikam-4.4.0/extra/kipi-plugins/timeadjust/kipiplugin_timeadjust.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=TimeDateAdjust
Name=TimeDateAdjust
Name[ar]=ضبط‌التاريخ‌الوقت
Name[ast]=TimeDateAdjust
Name[bg]=Нагласяване на дата и час
Name[bs]=Podešavanje vremena i datuma
Name[ca]=TimeDateAdjust
Name[ca@valencia]=TimeDateAdjust
Name[cs]=Úprava data a času
Name[da]=TimeDateAdjust
Name[de]=Zeit/Datum einstellen
Name[el]=TimeDateAdjust
Name[en_GB]=TimeDateAdjust
Name[es]=Ajustar fecha y hora
Name[et]=Aja kohendamine
Name[eu]=Ordua eta data doitzea
Name[fi]=Päiväyksen tarkistus
Name[fr]=Ajuster l'heure et la date
Name[ga]=TimeDateAdjust
Name[gl]=TimeDateAdjust
Name[he]=שינוי תאריך ושעה
Name[hne]=टाइम-डेट-एडजस्ट
Name[hu]=Dátum és idő beállítás
Name[is]=TimeDateAdjust
Name[it]=Regolazione di data e ora
Name[ja]=TimeDateAdjust
Name[km]=លៃតម្រូវ​កាលបរិច្ឆេទ/ពេលវេលា
Name[ko]=TimeDateAdjust
Name[lv]=Laika un datuma korekcija
Name[nb]=TimeDateAdjust
Name[nds]=TietDatumtopassen
Name[nl]=Tijd/DatumAanpassen
Name[pa]=ਟਾਈਮ ਮਿਤੀ ਅਡਜੱਸਟ
Name[pl]=DostrajanieCzasuDaty
Name[pt]=Ajuste de Data e Hora
Name[pt_BR]=Ajuste de data e hora
Name[ro]=Ajustare dată și oră
Name[ru]=Настройка даты и времени
Name[sk]=Oprava dátumu a času
Name[sl]=TimeDateAdjust
Name[sq]=Kohë Datë Rregullo
Name[sv]=Justera datum och tid
Name[th]=ปรับแก้ค่าวันที่และเวลาของภาพ
Name[tr]=Tarih Saat Ayarla
Name[uk]=TimeDateAdjust
Name[x-test]=xxTimeDateAdjustxx
Name[zh_CN]=时间数据调整
Name[zh_TW]=時間日期調整
Comment=A tool to adjust date and time
Comment[ast]=Una ferramienta p'axustar la data y la hora
Comment[bg]=Инструмент за нагласяване на датата и часа
Comment[bs]=Alat za podešavanje datuma i vremena
Comment[ca]=Una eina per a ajustar la data i l'hora
Comment[ca@valencia]=Una eina per a ajustar la data i l'hora
Comment[cs]=Nástroj pro úpravu data a času
Comment[da]=Et værktøj til at justere dato og tidspunkt
Comment[de]=Ein Werkzeug, um Datum und Zeit zu justieren.
Comment[el]=Εργαλείο ρύθμισης ημερομηνίας και ώρας
Comment[en_GB]=A tool to adjust date and time
Comment[es]=Una herramienta para ajustar la fecha y hora
Comment[et]=Tööriist kuupäeva ja kellaaja kohandamiseks
Comment[eu]=Ordua eta data doitzeko tresna
Comment[fr]=Un outil d'ajustement de la date et de l'heure
Comment[ga]=Uirlis a choigeartaíonn an dáta agus an t-am
Comment[gl]=Unha ferramenta para axustar a data e a hora
Comment[he]=כלי לשינוי תאריך ושעה
Comment[hne]=तारीक अउ समय ल एडजस्ट करे के एक औजार
Comment[hu]=Egy eszköz dátum és idő beállításához
Comment[is]=Verkfæri til að breyta dagsetningu og tímamerkjum mynda
Comment[it]=Uno strumento per regolare la data e l'ora
Comment[ja]=日付と時刻を調整するツール
Comment[km]=ឧបករណ៍​ត្រូវ​លៃតម្រូវ​កាលបរិច្ឆេទ និង​ពេលវេលា
Comment[lv]=Rīks laika un datuma koriģēšanai
Comment[nb]=Et verktøy for å justere dato og klokkeslett
Comment[nds]=En Warktüüch, mit dat sik Datum un Tiet topassen laat
Comment[nl]=Een hulpmiddel voor het aanpassen van datum en tijd
Comment[pa]=ਮਿਤੀ ਅਤੇ ਟਾਈਮ ਅਡਜੱਸਟ ਕਰਨ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do dostrajania daty i czasu
Comment[pt]=Uma ferramenta para ajustar a data e hora
Comment[pt_BR]=Uma ferramenta para ajustar a data e a hora
Comment[ro]=O unealtă pentru ajustarea datei și orei 
Comment[ru]=Инструмент для настройки даты и времени
Comment[sk]=Nástroj na opravu dátumu a času
Comment[sl]=Orodje za nastavljanje datuma in časa
Comment[sq]=Një mjet për të rregulluar datën dhe orën
Comment[sv]=Ett verktyg för att justera datum och tid
Comment[th]=เครื่องมือในการปรับแก้วันที่และเวลาของภาพ
Comment[tr]=Tarihi ve saati ayarlamak için bir araç
Comment[uk]=Інструмент для налаштування дати і часу
Comment[x-test]=xxA tool to adjust date and timexx
Comment[zh_CN]=一个调整日期和时间的工具
Comment[zh_TW]=調整日期和時間的工具
Type=Service
Icon=kipi-timeadjust
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_timeadjust
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
